<?php
/**
 * Uroan functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package uroan
 */
if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

#-----------------------------------------------------------------#
# Defined Constants
#-----------------------------------------------------------------#/
define('UROAN_THEME_NAME', 'uroan');
if (!defined('UROAN_PATH')) define('UROAN_PATH', get_template_directory());
if (!defined('UROAN_URL')) define('UROAN_URL', get_template_directory_uri());
define('UROAN_THEME_DIR', wp_normalize_path(UROAN_PATH . '/'));
define('UROAN_THEME_URI', preg_replace('/^http(s)?:/', '', UROAN_URL) . '/');
define('UROAN_CHILD_PATH', get_stylesheet_directory());
defined('UROAN_USER_LOGGED') or define('UROAN_USER_LOGGED', is_user_logged_in());


#-----------------------------------------------------------------#
# Site Content Width
#-----------------------------------------------------------------#/
if (!isset($content_width)) $content_width = 640;

if (!class_exists('Uroan_Theme_Setup')) {

    class Uroan_Theme_Setup
    {

        public function __construct() {

            /* includes_files Theme Files */

            add_action('after_setup_theme', array($this, 'includes_files'), 4);

            /* Main Theme Options */

            add_action('after_setup_theme', array($this, 'theme_support'));

            /* Register Widget */
            add_action('widgets_init', array($this, 'uroan_widgets_init'));

        }

        public function includes_files() {
            /**
             * Implement the Custom Header feature.
             */
            require UROAN_PATH . '/inc/custom-header.php';

            /**
             * Custom template tags for this theme.
             */
            require UROAN_PATH . '/inc/template-tags.php';

            /**
             * Functions which enhance the theme by hooking into WordPress.
             */
            require UROAN_PATH . '/inc/template-functions.php';
            require UROAN_PATH . '/inc/template-post.php';

            /**
             * Customizer additions.
             */
            require UROAN_PATH . '/inc/customizer.php';

            /**
             * Enqueue.
             */

            require UROAN_PATH . '/inc/uroan-enqueue.php';

            /**
             * Navwalker additions.
             */
            require UROAN_PATH . '/inc/bootstrap-navwalker.php';
            require UROAN_PATH . '/inc/uroan-nav-walker.php';

            require UROAN_PATH . '/inc/uroan-accordion-walker.php';


            /**
             * Comment.
             */
            require UROAN_PATH . '/inc/uroan_comment.php';

            /**
             * Admin Page.
             */
            require UROAN_PATH . '/inc/admin/admin.php';
            require UROAN_PATH . '/inc/admin/admin-init.php';

            /**
             * Breadcrumb.
             */
            require UROAN_PATH . '/inc/breadcrumb.php';

            /**
             * Load Jetpack compatibility file.
             */
            if (defined('JETPACK__VERSION')) {
                require UROAN_PATH . '/inc/jetpack.php';
            }

            /**
             * Load WooCommerce compatibility file.
             */
            if (class_exists('WooCommerce')) {
                require UROAN_PATH . '/inc/woocommerce.php';
                require UROAN_PATH . '/inc/template-product.php';
                require UROAN_PATH . '/inc/vendor/woo-single-product-structure.php';
            }
            
           
         
            if (!is_customize_preview() && is_admin()) {
                require_once(UROAN_PATH . '/inc/admin/merlin/vendor/autoload.php');
                require_once(UROAN_PATH . '/inc/admin/merlin/class-merlin.php');
                require_once(UROAN_PATH . '/inc/admin/merlin/merlin-config.php');
                require_once(UROAN_PATH . '/inc/admin/merlin/merlin-filters.php');
            }


        }


        public function theme_support() {
            // Set our theme version.
            if (!defined('UROAN_VERSION')) {
                // Replace the version number of the theme on each release.
                define('UROAN_VERSION', '1.4.1');
            }
            /*
             * Make theme available for translation.
             * Translations can be filed in the /languages/ directory.
             * If you're building a theme based on Uroan, use a find and replace
             * to change 'uroan' to the name of your theme in all the template files.
             */
            load_theme_textdomain('uroan', UROAN_PATH . '/languages');

            // Add default posts and comments RSS feed links to head.
            add_theme_support('automatic-feed-links');

            add_filter('wpcf7_autop_or_not', '__return_false');

            /*
             * Let WordPress manage the document title.
             * By adding theme support, we declare that this theme does not use a
             * hard-coded <title> tag in the document head, and expect WordPress to
             * provide it for us.
             */
            add_theme_support('title-tag');

            /*
             * Enable support for Post Thumbnails on posts and pages.
             *
             * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
             */
            add_theme_support('post-thumbnails');


            add_image_size('uroan-blog-sthome-one', 740, 540, true);
            add_image_size('uroan-blog-sthome-two', 430, 300, true);
            add_image_size('uroan-blog-sthome-three', 370, 417, true);
            add_image_size('uroan-blog-sthome-four', 370, 300, true);
            add_image_size('uroan-blog-sthome-five', 570, 400, true);
            add_image_size('uroan-navigation-image', 80, 80, true);
            add_image_size('uroan-blog-side-square', 88, 88, true);
            add_image_size('uroan-single-portfolio-thumbnail', 570, 710, true);
            add_image_size('uroan-portfolio-style-two', 120, 120, true);
            add_image_size('uroan-portfolio-style-four', 306, 340, true);
            add_image_size('uroan-product-quick-view', 488, 683, true);
            add_image_size('uroan-hero-product-thumbnail', 120, 112, true);
            add_image_size('uroan-blog-style-one-thumbnail', 416, 382, true);
            add_image_size('uroan-blog-style-two-thumbnail', 416, 483, true);
            add_image_size('uroan-product-single-thumbnail', 91, 83, true);

            // Image Size Cropping When Upload an image smaller than the size
            if (!function_exists('uroan_thumbnail_upload_scale')) {
                function uroan_thumbnail_upload_scale($default, $orig_w, $orig_h, $new_w, $new_h, $crop) {

                    if (!$crop) return null; // let the wordpress default function handle this

                    $aspect_ratio = $orig_w / $orig_h;
                    $size_ratio = max($new_w / $orig_w, $new_h / $orig_h);

                    $crop_w = round($new_w / $size_ratio);
                    $crop_h = round($new_h / $size_ratio);

                    $s_x = floor(($orig_w - $crop_w) / 2);
                    $s_y = floor(($orig_h - $crop_h) / 2);

                    return array(0, 0, (int)$s_x, (int)$s_y, (int)$new_w, (int)$new_h, (int)$crop_w, (int)$crop_h);
                }
            }
            add_filter('image_resize_dimensions', 'uroan_thumbnail_upload_scale', 10, 6);


            // This theme uses wp_nav_menu() in one location.
            register_nav_menus(
                array(
                    'main' => esc_html__('Main Menu', 'uroan'),
                    'account-menu' => esc_html__('Account Menu', 'uroan'),
                )
            );

            /*
             * Switch default core markup for search form, comment form, and comments
             * to output valid HTML5.
             */
            add_theme_support(
                'html5',
                array(
                    'search-form',
                    'comment-form',
                    'comment-list',
                    'gallery',
                    'caption',
                    'style',
                    'script',
                )
            );

            // Set up the WordPress core custom background feature.
            add_theme_support(
                'custom-background',
                apply_filters(
                    'uroan_custom_background_args',
                    array(
                        'default-color' => 'ffffff',
                        'default-image' => '',
                    )
                )
            );

            // Add theme support for selective refresh for widgets.
            add_theme_support('customize-selective-refresh-widgets');


            /**
             * Add support for core custom logo.
             *
             * @link https://codex.wordpress.org/Theme_Logo
             */
            add_theme_support(
                'custom-logo',
                array(
                    'height' => 250,
                    'width' => 250,
                    'flex-width' => true,
                    'flex-height' => true,
                )
            );


            #-----------------------------------------------------------------#
# Gutenberg
#-----------------------------------------------------------------#/
            // Theme supports wide images, galleries and videos.
            add_theme_support('align-wide');
            add_theme_support('wp-block-styles');
            add_theme_support('editor-styles');
            add_theme_support('responsive-embeds');
            add_theme_support('custom-units');

            remove_theme_support('widgets-block-editor');


            add_editor_style('style-editor.css');
            add_editor_style('https://fonts.googleapis.com/css2?family=Open+Sans&family=Quicksand:wght@500;600;700&display=swap');


            // Add custom editor font sizes.
            add_theme_support(
                'editor-font-sizes',
                array(
                    array(
                        'name' => esc_attr__('Small', 'uroan'),
                        'shortName' => esc_attr__('S', 'uroan'),
                        'size' => 16,
                        'slug' => 'small',
                    ),
                    array(
                        'name' => esc_attr__('Normal', 'uroan'),
                        'shortName' => esc_attr__('M', 'uroan'),
                        'size' => 18,
                        'slug' => 'normal',
                    ),
                    array(
                        'name' => esc_attr__('Large', 'uroan'),
                        'shortName' => esc_attr__('L', 'uroan'),
                        'size' => 24,
                        'slug' => 'large',
                    ),
                    array(
                        'name' => esc_attr__('Huge', 'uroan'),
                        'shortName' => esc_attr__('XL', 'uroan'),
                        'size' => 42,
                        'slug' => 'huge',
                    ),
                )
            );

            // Make specific theme colors available in the editor.
            add_theme_support('editor-color-palette', array(
                array(
                    'name' => __('Light gray', 'uroan'),
                    'slug' => 'light-gray',
                    'color' => '#f5f5f5',
                ),
                array(
                    'name' => __('Medium gray', 'uroan'),
                    'slug' => 'medium-gray',
                    'color' => '#999',
                ),
                array(
                    'name' => __('Dark gray', 'uroan'),
                    'slug' => 'dark-gray',
                    'color' => '#222a36',
                ),

                array(
                    'name' => __('Purple', 'uroan'),
                    'slug' => 'purple',
                    'color' => '#5a00f0',
                ),

                array(
                    'name' => __('Dark Blue', 'uroan'),
                    'slug' => 'dark-blue',
                    'color' => '#28375a',
                ),

                array(
                    'name' => __('Red', 'uroan'),
                    'slug' => 'red',
                    'color' => '#c44d58',
                ),

                array(
                    'name' => __('Yellow', 'uroan'),
                    'slug' => 'yellow',
                    'color' => '#ecca2e',
                ),

                array(
                    'name' => __('Green', 'uroan'),
                    'slug' => 'green',
                    'color' => '#64a500',
                ),

                array(
                    'name' => __('White', 'uroan'),
                    'slug' => 'white',
                    'color' => '#ffffff',
                ),
            ));

            add_theme_support('editor-font-sizes', array(
                array(
                    'name' => __('Small', 'uroan'),
                    'size' => 14,
                    'slug' => 'small'
                ),
                array(
                    'name' => __('Normal', 'uroan'),
                    'size' => 16,
                    'slug' => 'normal'
                ),
                array(
                    'name' => __('Large', 'uroan'),
                    'size' => 36,
                    'slug' => 'large'
                ),
                array(
                    'name' => __('Huge', 'uroan'),
                    'size' => 40,
                    'slug' => 'huge'
                )
            ));


        }


        public function uroan_widgets_init() {
            register_sidebar(
                array(
                    'name' => esc_html__('Sidebar', 'uroan'),
                    'id' => 'uroan-sidebar',
                    'description' => esc_html__('Add widgets here.', 'uroan'),
                    'before_widget' => '<section id="%1$s" class="widget %2$s global-animated-hidden global-animated-up">',
                    'after_widget' => '</section>',
                    'before_title' => '<h2 class="widget-title">',
                    'after_title' => '</h2>',
                )
            );

            register_sidebar(
                array(
                    'name' => esc_html__('Woo Archive', 'uroan'),
                    'id' => 'uroan-woo-sidebar',
                    'description' => esc_html__('Add widgets here.', 'uroan'),
                    'before_widget' => '<section id="%1$s" class="widget %2$s global-animated-hidden global-animated-up">',
                    'after_widget' => '</section>',
                    'before_title' => '<h2 class="widget-title">',
                    'after_title' => '</h2>',
                )
            );

            register_sidebar(
                array(
                    'name' => esc_html__('Case Study Sidebar', 'uroan'),
                    'id' => 'uroan-cs-sidebar',
                    'description' => esc_html__('Add widgets here.', 'uroan'),
                    'before_widget' => '<section id="%1$s" class="widget %2$s global-animated-hidden global-animated-up">',
                    'after_widget' => '</section>',
                    'before_title' => '<h2 class="widget-title">',
                    'after_title' => '</h2>',
                )
            );
            register_sidebar(
                array(
                    'name' => esc_html__('Header Language Bar', 'uroan'),
                    'id' => 'header_language_bar',
                    'description' => esc_html__('Add Language Code here.', 'uroan'),
                    'before_widget' => '',
                    'after_widget' => '',
                    'before_title' => '',
                    'after_title' => '',
                )
            );
            register_sidebar(
                array(
                    'name' => esc_html__('Header Currency', 'uroan'),
                    'id' => 'header_currency',
                    'description' => esc_html__('Add Currency here.', 'uroan'),
                    'before_widget' => '',
                    'after_widget' => '',
                    'before_title' => '',
                    'after_title' => '',
                )
            );
            register_sidebar(
                array(
                    'name' => esc_html__('Footer About', 'uroan'),
                    'id' => 'uroan-about-widget',
                    'description' => esc_html__('Add widgets here.', 'uroan'),
                    'before_widget' => '<div id="%1$s" class="%2$s ur3-footer-widget">',
                    'after_widget' => '</div>',
                    'before_title' => '',
                    'after_title' => '',
                )
            );
            register_sidebar(
                array(
                    'name' => esc_html__('Footer Userful Links', 'uroan'),
                    'id' => 'uroan-useful-links-widget',
                    'description' => esc_html__('Add widgets here.', 'uroan'),
                    'before_widget' => '<div id="%1$s" class="%2$s ur3-footer-widget">',
                    'after_widget' => '</div>',
                    'before_title' => '<h4 class="text-white widget-title mb-40 fw-normal">',
                    'after_title' => '</h4>',
                )
            );
            register_sidebar(
                array(
                    'name' => esc_html__('Footer Userful Links Two', 'uroan'),
                    'id' => 'uroan-useful-links-widget-two',
                    'description' => esc_html__('Add widgets here.', 'uroan'),
                    'before_widget' => '<div id="%1$s" class="%2$s ur3-footer-widget">',
                    'after_widget' => '</div>',
                    'before_title' => '<h4 class="text-white widget-title mb-40 fw-normal">',
                    'after_title' => '</h4>',
                )
            );
            register_sidebar(
                array(
                    'name' => esc_html__('Footer Userful Links Three', 'uroan'),
                    'id' => 'uroan-useful-links-widget-three',
                    'description' => esc_html__('Add widgets here.', 'uroan'),
                    'before_widget' => '<div id="%1$s" class="%2$s ur3-footer-widget">',
                    'after_widget' => '</div>',
                    'before_title' => '<h4 class="text-white widget-title mb-40 fw-normal">',
                    'after_title' => '</h4>',
                )
            );
            register_sidebar(
                array(
                    'name' => esc_html__('Footer Style One Newsletter', 'uroan'),
                    'id' => 'uroan-footer-style-one-newsletter',
                    'description' => esc_html__('Add widgets here.', 'uroan'),
                    'before_widget' => '<div id="%1$s" class="%2$s">',
                    'after_widget' => '</div>',
                    'before_title' => '<h3 class="mb-4 text-white">',
                    'after_title' => '</h3>',
                )
            );
            register_sidebar(
                array(
                    'name' => esc_html__('Footer Style Two Newsletter', 'uroan'),
                    'id' => 'uroan-footer-style-two-newsletter',
                    'description' => esc_html__('Add widgets here.', 'uroan'),
                    'before_widget' => '<div id="%1$s" class="%2$s">',
                    'after_widget' => '</div>',
                    'before_title' => '<h3 class="mb-0 fw-regular text-white">',
                    'after_title' => '</h3>',
                )
            );
            register_sidebar(
                array(
                    'name' => esc_html__('Footer Instagram Gallery', 'uroan'),
                    'id' => 'uroan-footer-instagram-gallery',
                    'description' => esc_html__('Add widgets here.', 'uroan'),
                    'before_widget' => '<div id="%1$s" class="%2$s">',
                    'after_widget' => '</div>',
                    'before_title' => '',
                    'after_title' => '',
                )
            );
        }


    }

    new Uroan_Theme_Setup;

}

function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1717516676868';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        